@@ -1,7 +1,8 @@
-from .settings import ON_DELETE, AUTH_USER_MODEL
 from django.db import models
 from django.db.models import Model
 
+from .settings import AUTH_USER_MODEL, ON_DELETE
+
 
 class AuthoredModel(Model):
     """
