@@ -1,6 +1,6 @@
 from bitsoframework.media.image.serializers import ImageSerializer
 from bitsoframework.media.serializers import AbstractFileMediaSerializer
-from bitsoframework.media.settings import Document, PREVIEW_ENABLED
+from bitsoframework.media.settings import PREVIEW_ENABLED, Document
 
 
 class DocumentSerializer(AbstractFileMediaSerializer):
