@@ -1,4 +1,4 @@
-from bitsoframework.utils.models import set_attrs, get_choice_label
+from bitsoframework.utils.models import get_choice_label, set_attrs
 from bitsoframework.vos import AbstractVO
 
 
