@@ -1,6 +1,6 @@
 from rest_framework.routers import DefaultRouter
 
-from bitsoframework.metadata.views import *
+from bitsoframework.metadata.views import MetadataModelViewSet
 
 router = DefaultRouter()
 
