@@ -16,7 +16,7 @@ class MetadataModelViewSet(AbstractViewSet):
     def get(self):
         pass
 
-    @action(detail=False, url_path="(?P<app_label>[-\w]+)/(?P<model_name>[-\w]+)")
+    @action(detail=False, url_path="(?P<app_label>[-\w]+)/(?P<model_name>[-\w]+)")  # noqa W605
     def get_by_name(self, request, app_label, model_name):
         instance = self.service.get_model(app_label, model_name)
 
