@@ -1,4 +1,4 @@
-from bitsoframework.utils.models import get_model_class, get_field, exists, diff_list
+from bitsoframework.utils.models import diff_list, exists, get_model_class
 
 
 class Differ(object):
@@ -13,7 +13,6 @@ class Differ(object):
         result = {}
 
         for name in properties:
-            field = get_field(self.model_class, name) or getattr(self.model_class, name)
             new_value = getattr(self.new_record, name)
             old_value = getattr(self.old_record or self.new_record, name)
 
