@@ -1,4 +1,4 @@
-from .serializers import TagListSerializerField, TaggitSerializer
+from .serializers import TaggitSerializer, TagListSerializerField
 
 
 class TaggableSerializer(TaggitSerializer):
