@@ -1,7 +1,7 @@
-from datetime import timedelta, datetime
+from datetime import datetime, timedelta
 
 from django.conf import settings
-from django.utils.timezone import is_aware, make_aware, is_naive, make_naive
+from django.utils.timezone import is_aware, is_naive, make_aware, make_naive
 
 
 def fix_timezone(value, timezone=None, is_dst=None):
